Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4251)

Unified Diff: chrome/browser/chromeos/arc/policy/arc_android_management_checker.h

Issue 2450683002: Clean up retry-delay-time code. (Closed)
Patch Set: Address comments. Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/chromeos/arc/policy/arc_android_management_checker.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chromeos/arc/policy/arc_android_management_checker.h
diff --git a/chrome/browser/chromeos/arc/policy/arc_android_management_checker.h b/chrome/browser/chromeos/arc/policy/arc_android_management_checker.h
index b72641eaa25a6f60c9f397b90a26aa5e2a4ffcf1..dc50f834d53f73b0c456dff189a8f0725a413428 100644
--- a/chrome/browser/chromeos/arc/policy/arc_android_management_checker.h
+++ b/chrome/browser/chromeos/arc/policy/arc_android_management_checker.h
@@ -9,6 +9,7 @@
#include "base/macros.h"
#include "base/memory/weak_ptr.h"
+#include "base/time/time.h"
#include "chrome/browser/chromeos/policy/android_management_client.h"
#include "google_apis/gaia/oauth2_token_service.h"
@@ -51,8 +52,8 @@ class ArcAndroidManagementChecker : public OAuth2TokenService::Observer {
// retry in foreground mode and result is passed to delegate directly.
bool background_mode_;
- // Keeps current retry time for background mode.
- int retry_time_ms_;
+ // Keeps current retry delay.
+ base::TimeDelta retry_delay_;
policy::AndroidManagementClient android_management_client_;
« no previous file with comments | « no previous file | chrome/browser/chromeos/arc/policy/arc_android_management_checker.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698